Glossary — FracAbility 0.1.0 documentation

Skip to main content
`Ctrl`+`K`

# Glossary

Digital Outcrop Models (DOMs)

  Qualitative three-dimensional representations of suitable rock outcrops

Interpretational boundaries

  Areas in which it is possible to carry out fracture interpretation

Interpretational voids

  Internal areas of the boundaries in which it is impossible to carry out fracture interpretation

Survival analysis

  Statistical technique to correct for left, right and interval censoring

Topology

  Topology studies the set of properties of an object (components) that are preserved through deformation without tearing or ripping (Mallet 2002) and describes the way different parts of an object are connected.